@@ -5,18 +5,14 @@ from trytond.model import fields
 from trytond.pyson import Eval
 
 
-__all__ = ['Template', 'Product']
-
-
-class Template:
-    __metaclass__ = PoolMeta
+class Template(metaclass=PoolMeta):
     __name__ = 'product.template'
-    landed_cost = fields.Boolean('Landed Cost', states={
-            'readonly': ~Eval('active', True),
+    landed_cost = fields.Boolean(
+        "Landed Cost",
+        states={
             'invisible': Eval('type') != 'service',
-            }, depends=['active', 'type'])
+            }, depends=['type'])
 
 
-class Product:
-    __metaclass__ = PoolMeta
+class Product(metaclass=PoolMeta):
     __name__ = 'product.product'
